@@ -1,15 +1,10 @@
 """Asset Entity"""
 
-import sys
-from typing import Any
+from typing import Any, Self
 
-from pydantic import BaseModel, Field, model_validator
-
-if sys.version_info >= (3, 11):
-  from typing import Self
-else:
-  from typing_extensions import Self
+from pydantic import BaseModel, Field, field_validator, model_validator
 
+from .asset_contact import AssetContact
 from .asset_operation_mode import AssetOperationMode
 from .custom_field import CustomField
 from .device import Device
@@ -20,14 +15,20 @@ from .static_position import StaticPosition
 class Asset(BaseModel):
   """Asset entity definition"""
 
-  pk: int = Field(description='Defines the primary key of the asset')
+  model_config = {
+    'json_encoders': {
+      AssetOperationMode: lambda v: v.value,
+    }
+  }
+
+  pk: int = Field(description='Defines the primary key of the asset', alias='id')
   name: str = Field(description='Defines the name of the asset')
   vin: str | None = Field(
     default=None,
     description='Defines the serial number of the asset, may be an VIN, or any other unique identifier',
   )
   plate: str | None = Field(default=None, description='Defines the plate number of the asset')
-  asset_type: int | None = Field(description='Defines the type of the asset', alias='kind_id', default=None)
+  kind_id: int | None = Field(description='Defines the type of the asset', default=None)
   operation_mode: AssetOperationMode = Field(description='Defines the operation mode of the asset')
   sensors: list[Sensor] = Field(default_factory=list, description='Defines the list of sensors of the asset')
   custom_fields: list[CustomField] = Field(
@@ -41,6 +42,20 @@ class Asset(BaseModel):
     description='Static position of the asset',
   )
 
+  @field_validator('static_position', mode='before')
+  def _validate_static_position(cls: Self, value: Any) -> StaticPosition | None:
+    """Validate static position"""
+    if isinstance(value, dict):
+      try:
+        return StaticPosition.model_validate(value)
+      except Exception:
+        return None
+
+    if isinstance(value, StaticPosition):
+      return value
+
+    return None
+
   points: list[StaticPosition] = Field(
     default_factory=list,
     description='List of static positions for the asset. The altitude of StaticPosition is not used in this case.',
@@ -75,7 +90,7 @@ class Asset(BaseModel):
 
     return None
 
-  contacts: list[str] = Field(
+  contacts: list[AssetContact] = Field(
     default_factory=list,
     description='Defines the list of contacts of the asset, used for notifications',
   )
@@ -84,3 +99,8 @@ class Asset(BaseModel):
     default=None,
     description='Owner ID',
   )
+
+  @property
+  def asset_type(self: Self) -> int | None:
+    """Get asset type"""
+    return self.kind_id
