@@ -1,15 +1,10 @@
 """Asset Operation Mode"""
 
-import sys
-from enum import Enum
-
-if sys.version_info >= (3, 11):
-  from typing import Self
-else:
-  from typing_extensions import Self
+from enum import StrEnum
+from typing import Self
 
 
-class AssetOperationMode(str, Enum):
+class AssetOperationMode(StrEnum):
   """
   Asset Operation mode definition
   It's an enum of the operation mode of the asset.
