@@ -1,13 +1,8 @@
-import sys
-from enum import Enum
-
-if sys.version_info >= (3, 11):
-  from typing import Self
-else:
-  from typing_extensions import Self
+from enum import StrEnum
+from typing import Self
 
 
-class CaseStatus(str, Enum):
+class CaseStatus(StrEnum):
   """Case status enum"""
 
   PENDING = 'PENDING'
