@@ -1,15 +1,10 @@
 """Chart Data type"""
 
-import sys
-from enum import Enum
-
-if sys.version_info >= (3, 11):
-  from typing import Self
-else:
-  from typing_extensions import Self
+from enum import StrEnum
+from typing import Self
 
 
-class ChartDataType(str, Enum):
+class ChartDataType(StrEnum):
   """
   Chart Data Type
   """
