@@ -1,13 +1,8 @@
-import sys
-from enum import Enum
-
-if sys.version_info >= (3, 11):
-  from typing import Self
-else:
-  from typing_extensions import Self
+from enum import StrEnum
+from typing import Self
 
 
-class MapCenterType(str, Enum):
+class MapCenterType(StrEnum):
   """Map Chart center type"""
 
   FIXED = 'FIXED'
