@@ -1,11 +1,10 @@
 """Checkpoints entitites"""
 
 from datetime import datetime
+from enum import StrEnum
 
 from pydantic import BaseModel, Field
 
-from layrz_sdk.backwards import StrEnum
-
 from .waypoint import Waypoint, WaypointRef
 
 
@@ -45,7 +44,7 @@ class CheckpointRef(BaseModel):
   }
 
   pk: int = Field(description='Checkpoint ID', alias='id')
-  asset_id: int = Field(description='Asset ID')
+  name: str = Field(description='Checkpoint name')
   waypoints: list[WaypointRef] = Field(description='List of waypoints', default_factory=list)
 
   operation_mode: CheckpointOperationMode = Field(
