@@ -1,15 +1,10 @@
 """Twilio Notification Type Enum"""
 
-import sys
-from enum import Enum
-
-if sys.version_info >= (3, 11):
-  from typing import Self
-else:
-  from typing_extensions import Self
+from enum import StrEnum
+from typing import Self
 
 
-class TwilioNotificationType(str, Enum):
+class TwilioNotificationType(StrEnum):
   """
   Twilio Notification Type Enum definition
   """
