@@ -1,11 +1,10 @@
 """Waypoint entity"""
 
 from datetime import datetime, timedelta
+from enum import StrEnum
 
 from pydantic import BaseModel, Field
 
-from layrz_sdk.backwards import StrEnum
-
 from .geofence import Geofence
 
 
@@ -26,12 +25,19 @@ class WaypointKind(StrEnum):
 class Waypoint(BaseModel):
   """Waypoint entity definition"""
 
-  pk: int = Field(description='Waypoint ID')
-  geofence: Geofence = Field(description='Geofence object')
-  start_at: datetime = Field(description='Waypoint start date')
-  end_at: datetime = Field(description='Waypoint end date')
-  sequence_real: int = Field(description='Real sequence number')
-  sequence_ideal: int = Field(description='Ideal sequence number')
+  model_config = {
+    'json_encoders': {
+      datetime: lambda v: v.timestamp(),
+    },
+  }
+
+  pk: int = Field(description='Waypoint ID', alias='id')
+  geofence: Geofence | None = Field(default=None, description='Geofence object')
+  geofence_id: int | None = Field(default=None, description='Geofence ID')
+  start_at: datetime | None = Field(default=None, description='Waypoint start date')
+  end_at: datetime | None = Field(default=None, description='Waypoint end date')
+  sequence_real: int = Field(..., description='Real sequence number')
+  sequence_ideal: int = Field(..., description='Ideal sequence number')
 
 
 class WaypointRef(BaseModel):
